@@ -6,6 +6,7 @@ from qa4sm_reader import globals
 import numpy as np
 import pandas as pd
 import os.path
+import copy
 
 import seaborn as sns
 import matplotlib.pyplot as plt
@@ -374,7 +375,7 @@ def style_map(
 
     return ax
 
-def make_watermark(fig, placement=globals.watermark_pos, for_map=False, offset=0.02):
+def make_watermark(fig, placement=globals.watermark_pos, for_map=False, offset=0.03):
     """
     Adds a watermark to fig and adjusts the current axis to make sure there
     is enough padding around the watermarks.
@@ -681,6 +682,17 @@ def mapplot(
             v_min, v_max = get_value_range(df, metric=None, diff_map=True)
             cmap = globals._diff_colormaps[metric]
 
+        # mask values outside range (e.g. for negative STDerr from TCA)
+        if metric in globals._metric_mask_range.keys():
+            mask_under, mask_over = globals._metric_mask_range[metric]  # get values from scratch to disregard quantiles
+            cmap = copy.copy(cmap)
+            if mask_under is not None:
+                v_min = mask_under
+                cmap.set_under("red")
+            if mask_over is not None:
+                v_max = mask_over
+                cmap.set_over("red")
+
         # initialize plot
         fig, ax, cax = init_plot(figsize, dpi, add_cbar, projection)
 
@@ -740,7 +752,6 @@ def plot_spatial_extent(
     reg_grid : bool, default is False,
         plotting oprion for regular grids (satellites)
     """
-    # todo: adjust figsize to shown polygons
     fig, ax, cax = init_plot(figsize=globals.map_figsize, dpi=globals.dpi)
     legend_elements = []
     # plot polygons
@@ -826,8 +837,6 @@ def plot_spatial_extent(
                     )
                 else:
                     continue
-    # create legend
-    plt.legend(bbox_to_anchor=(1, 1), fontsize='medium')
     # style plot
     make_watermark(fig, globals.watermark_pos, offset=0)
     title_style = {"fontsize": 12}
@@ -837,6 +846,12 @@ def plot_spatial_extent(
     d_lat = abs(union.bounds[1] - union.bounds[3])* 1/8
     plot_extent = (union.bounds[0] - d_lon, union.bounds[2] + d_lon,
                    union.bounds[1] - d_lat, union.bounds[3] + d_lat)
-    plt.tight_layout()
     grid_intervals = [1, 5, 10, 30]
     style_map(ax, plot_extent, grid_intervals=grid_intervals)
+    # create legend
+    plt.legend(
+        loc="lower left",
+        fontsize='small',
+        framealpha=0.4,
+        edgecolor='black'
+    )
